@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['in_20conjunction_20with_20the_20update_20add_20functions_0',['Position helper functions (use in conjunction with the update&amp;add functions)',['../group__xmlPosition.html',1,'']]],
+  ['in_20conjunction_20with_20the_20update_20add_20functions_0',['Position helper functions (use in conjunction with the update&amp;amp;add functions)',['../group__xmlPosition.html',1,'']]],
   ['in_20place_20construction_1',['Tools for in-place construction',['../group__OFin__place__helpers.html',1,'']]],
   ['include_20binary_20data_20inside_20xml_20strings_20using_20base64_20encoding_2',['Helper class to include binary data inside XML strings using &quot;Base64 encoding&quot;.',['../group__XMLParserBase64Tool.html',1,'']]],
   ['inside_20xml_20strings_20using_20base64_20encoding_3',['Helper class to include binary data inside XML strings using &quot;Base64 encoding&quot;.',['../group__XMLParserBase64Tool.html',1,'']]]
