@@ -2,5 +2,6 @@ var searchData=
 [
   ['dcmquantcomponent_0',['DcmQuantComponent',['../diqttype_8h.html#a3af3676a7775ff8343be11a3af411bb8',1,'diqttype.h']]],
   ['deviceparticipatingroleslist_1',['DeviceParticipatingRolesList',['../classTID1001__ObservationContext.html#aa085edcd384c7f6e917c508877d44ee6',1,'TID1001_ObservationContext']]],
-  ['difference_5ftype_2',['difference_type',['../classOFdirectory__iterator.html#a58fcbee50576ce5535720d8b76be4132',1,'OFdirectory_iterator']]]
+  ['difference_5ftype_2',['difference_type',['../classOFdirectory__iterator.html#a58fcbee50576ce5535720d8b76be4132',1,'OFdirectory_iterator']]],
+  ['distinctframepositions_3',['DistinctFramePositions',['../classOverlapUtil.html#a8be9b382f7652e8cab89a26f414de3f1',1,'OverlapUtil']]]
 ];
